@@ -2,6 +2,7 @@
 # -*- coding: utf-8 -*-
 
 import ipaddress
+import multiprocessing
 import os
 import pathlib
 import threading
@@ -46,6 +47,11 @@ class BaseTestReader(object):
     ]
     use_ip_objects = False
 
+    # fork doesn't work on Windows and spawn would involve pickling the reader,
+    # which isn't possible.
+    if os.name != "nt":
+        mp = multiprocessing.get_context("fork")
+
     def ipf(self, ip):
         if self.use_ip_objects:
             return ipaddress.ip_address(ip)
@@ -185,6 +191,54 @@ class BaseTestReader(object):
                     "expected_record for " + test["ip"] + " in " + test["file_name"],
                 )
 
+    def test_iterator(self):
+        tests = (
+            {
+                "database": "ipv4",
+                "expected": [
+                    "1.1.1.1/32",
+                    "1.1.1.2/31",
+                    "1.1.1.4/30",
+                    "1.1.1.8/29",
+                    "1.1.1.16/28",
+                    "1.1.1.32/32",
+                ],
+            },
+            {
+                "database": "ipv6",
+                "expected": [
+                    "::1:ffff:ffff/128",
+                    "::2:0:0/122",
+                    "::2:0:40/124",
+                    "::2:0:50/125",
+                    "::2:0:58/127",
+                ],
+            },
+            {
+                "database": "mixed",
+                "expected": [
+                    "1.1.1.1/32",
+                    "1.1.1.2/31",
+                    "1.1.1.4/30",
+                    "1.1.1.8/29",
+                    "1.1.1.16/28",
+                    "1.1.1.32/32",
+                    "::1:ffff:ffff/128",
+                    "::2:0:0/122",
+                    "::2:0:40/124",
+                    "::2:0:50/125",
+                    "::2:0:58/127",
+                ],
+            },
+        )
+
+        for record_size in [24, 28, 32]:
+            for test in tests:
+                f = f'tests/data/test-data/MaxMind-DB-test-{test["database"]}-{record_size}.mmdb'
+                reader = open_database(f, self.mode)
+                networks = [str(n) for (n, _) in reader]
+                self.assertEqual(networks, test["expected"], f)
+
     def test_decoder(self):
         reader = open_database(
             "tests/data/test-data/MaxMind-DB-test-decoder.mmdb", self.mode
@@ -440,41 +494,43 @@ class BaseTestReader(object):
         else:
             self.assertIsNotNone(metadata, "pure Python implementation returns value")
 
-    def test_multiprocessing(self):
-        self._check_concurrency(Process)
+    if os.name != "nt":
 
-    def test_threading(self):
-        self._check_concurrency(threading.Thread)
+        def test_multiprocessing(self):
+            self._check_concurrency(self.mp.Process)
 
-    def _check_concurrency(self, worker_class):
-        reader = open_database(
-            "tests/data/test-data/GeoIP2-Domain-Test.mmdb", self.mode
-        )
+        def test_threading(self):
+            self._check_concurrency(threading.Thread)
 
-        def lookup(pipe):
-            try:
-                for i in range(32):
-                    reader.get(self.ipf(f"65.115.240.{i}"))
-                pipe.send(1)
-            except:
-                pipe.send(0)
-            finally:
-                if worker_class is Process:
-                    reader.close()
-                pipe.close()
+        def _check_concurrency(self, worker_class):
+            reader = open_database(
+                "tests/data/test-data/GeoIP2-Domain-Test.mmdb", self.mode
+            )
 
-        pipes = [Pipe() for _ in range(32)]
-        procs = [worker_class(target=lookup, args=(c,)) for (p, c) in pipes]
-        for proc in procs:
-            proc.start()
-        for proc in procs:
-            proc.join()
+            def lookup(pipe):
+                try:
+                    for i in range(32):
+                        reader.get(self.ipf(f"65.115.240.{i}"))
+                    pipe.send(1)
+                except:
+                    pipe.send(0)
+                finally:
+                    if worker_class is self.mp.Process:
+                        reader.close()
+                    pipe.close()
 
-        reader.close()
+            pipes = [self.mp.Pipe() for _ in range(32)]
+            procs = [worker_class(target=lookup, args=(c,)) for (p, c) in pipes]
+            for proc in procs:
+                proc.start()
+            for proc in procs:
+                proc.join()
 
-        count = sum([p.recv() for (p, c) in pipes])
+            reader.close()
 
-        self.assertEqual(count, 32, "expected number of successful lookups")
+            count = sum([p.recv() for (p, c) in pipes])
+
+            self.assertEqual(count, 32, "expected number of successful lookups")
 
     def _check_metadata(self, reader, ip_version, record_size):
         metadata = reader.metadata()
@@ -619,7 +675,7 @@ class TestMemoryReader(BaseTestReader, unittest.TestCase):
 
 class TestFDReader(BaseTestReader, unittest.TestCase):
     def setUp(self):
-        self.open_database_patcher = mock.patch("reader_test.open_database")
+        self.open_database_patcher = mock.patch(__name__ + ".open_database")
         self.addCleanup(self.open_database_patcher.stop)
         self.open_database = self.open_database_patcher.start()
         self.open_database.side_effect = get_reader_from_file_descriptor
